[java-identity-provider] branch main updated: Update nit in log message.

Scott Cantor cantor.2 at osu.edu
Wed Feb 17 13:30:47 UTC 2021


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=33c432ada86213cf58ab8fa7676d19c95e1a6016

The following commit(s) were added to refs/heads/main by this push:
       new  33c432ada Update nit in log message.
33c432ada is described below

commit 33c432ada86213cf58ab8fa7676d19c95e1a6016
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Wed Feb 17 08:29:43 2021 -0500

    Update nit in log message.
---
 .../idp/attribute/resolver/dc/ldap/impl/LDAPDataConnector.java        | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/dc/ldap/impl/LDAPDataConnector.java b/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/dc/ldap/impl/LDAPDataConnector.java
index 8bdcdacc2..1143d71e0 100644
--- a/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/dc/ldap/impl/LDAPDataConnector.java
+++ b/idp-attribute-resolver-impl/src/main/java/net/shibboleth/idp/attribute/resolver/dc/ldap/impl/LDAPDataConnector.java
@@ -161,7 +161,7 @@ public class LDAPDataConnector extends AbstractSearchDataConnector<ExecutableSea
     }
 
 // CheckStyle: CyclomaticComplexity OFF
     /** Police SSL for JVM trust.
      * @throws ComponentInitializationException if we detect an SSL issue
      */
     private void policeForJVMTrust() throws ComponentInitializationException {
@@ -189,7 +189,7 @@ public class LDAPDataConnector extends AbstractSearchDataConnector<ExecutableSea
                 }
             }
         } catch (final GeneralSecurityException | LdapException e) {
-            log.debug("{} Failed to inspect SLL implementation", getLogPrefix(), e);
+            log.debug("{} Failed to inspect TLS implementation", getLogPrefix(), e);
         } finally {
             if (conn != null) {
                 try {
@@ -161,7 +161,7 @@ public class LDAPDataConnector extends AbstractSearchDataConnector<ExecutableSea
 
 // CheckStyle: CyclomaticComplexity OFF
-    /** Police SSL for JVM trust.
+    /** Police TLS for JVM trust.
      * @throws ComponentInitializationException if we detect an SSL issue
      */

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list